package de.inovex.academy.hadoop.candy;

import org.apache.hadoop.conf.Configured;
import org.apache.hadoop.fs.Path;
import org.apache.hadoop.io.IntWritable;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.mapreduce.Job;
import org.apache.hadoop.mapreduce.lib.input.FileInputFormat;
import org.apache.hadoop.mapreduce.lib.output.FileOutputFormat;
import org.apache.hadoop.util.Tool;
import org.apache.hadoop.util.ToolRunner;

import de.inovex.academy.hadoop.util.IntSumReducer;

public class ColorCount extends Configured implements Tool {

	@Override
	public int run(String[] args) throws Exception {

		Job job = new Job();

		job.setJarByClass( ColorCount.class );
		job.setJobName( "color-count" );

		FileInputFormat.addInputPath( job, new Path( args[0] ));
		FileOutputFormat.setOutputPath( job, new Path( args[1] ));

		job.setMapperClass( ColorMapper.class );
		job.setReducerClass( IntSumReducer.class );
		job.setNumReduceTasks( 6 ); // 6 different colors

		job.setOutputKeyClass( Text.class );
		job.setOutputValueClass( IntWritable.class );

		return job.waitForCompletion( true ) ? 0 : 1;
	}

	public static void main( String[] args ) throws Exception {
		int exitCode = ToolRunner.run( new ColorCount(), args);
		System.exit(exitCode);
	}

}
