package de.inovex.academy.hadoop.candy;

import java.io.IOException;

import org.apache.hadoop.io.DoubleWritable;
import org.apache.hadoop.io.IntWritable;
import org.apache.hadoop.io.LongWritable;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.mapreduce.Mapper;
import org.apache.hadoop.mapreduce.Reducer;
import org.apache.hadoop.mrunit.mapreduce.MapDriver;
import org.apache.hadoop.mrunit.mapreduce.MapReduceDriver;
import org.apache.hadoop.mrunit.mapreduce.ReduceDriver;
import org.junit.Before;
import org.junit.Test;

import de.inovex.academy.hadoop.util.IntAvgReducer;

public class AverageSizePerBagWithCounterTest {
    MapReduceDriver<LongWritable, Text, Text, IntWritable, Text, DoubleWritable> mapReduceDriver;
    MapDriver<LongWritable, Text, Text, IntWritable> mapDriver;
    ReduceDriver<Text, IntWritable, Text, DoubleWritable> reduceDriver;

  @Before
      public void setUp() {
      Mapper<LongWritable, Text, Text, IntWritable> mapper = 
	  new BagSizemmFilteringMapper();
      Reducer<Text, IntWritable, Text, DoubleWritable> reducer = 
	  new IntAvgReducer();
      mapDriver = new MapDriver<LongWritable, Text, Text, IntWritable>();
      mapDriver.setMapper(mapper);
      reduceDriver = new ReduceDriver<Text, IntWritable, Text, DoubleWritable>();
      reduceDriver.setReducer(reducer);
      mapReduceDriver = new MapReduceDriver<LongWritable, Text, Text, IntWritable, Text, DoubleWritable>();
      mapReduceDriver.setMapper(mapper);
      mapReduceDriver.setReducer(reducer);
  }



  @Test
      public void testMapperCrushed() throws IOException {
      mapDriver.withInput(new LongWritable(1), new Text("crushed\tcrushed\tcrushed\t-1\t-1\t-1"));
      mapDriver.withCounter( BagSizemmFilteringMapper.Malformed.CRUSHED, 1L );

      mapDriver.runTest();
  }

  @Test
      public void testMapperHappy() throws IOException {
      mapDriver.withInput(new LongWritable(1), new Text("red\tmilk\tS\t9\t30\t171"));
      mapDriver.withOutput(new Text("171"), new IntWritable( 9 ));
      mapDriver.withCounter( BagSizemmFilteringMapper.Malformed.CRUSHED, 0L );

      mapDriver.runTest();
  }


}